@@ -1,14 +1,14 @@
-import os
-from .utils import run_command
+from .utils import run_command, is_unix
 
 # -----------------------------------------------------------------------------
 
 def handle_install_command():
     
-    if os.name == "posix":
+    if is_unix():
         path_to_vcpkg = "vcpkg/vcpkg"
     else:
         path_to_vcpkg = "vcpkg/vcpkg.exe"
+    
     vcpkg_install = [path_to_vcpkg, "install"]
 
     run_command(vcpkg_install)
